#
# spec file for package python-pony
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# not compatible: https://github.com/ponyorm/pony/blob/v0.7.17/setup.py#L112
%define skip_python312 1
%define skip_python313 1
Name:           python-pony
Version:        0.7.19
Release:        2.3
Summary:        Pony Object-Relational Mapper
License:        Apache-2.0
URL:            https://ponyorm.com
Source:         https://files.pythonhosted.org/packages/source/p/pony/pony-%{version}.tar.gz
BuildRequires:  %{python_module base}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module sqlite3}
BuildRequires:  dos2unix
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python
BuildArch:      noarch
%python_subpackages

%description
Pony ORM is a object-relational mapper for Python. Using Pony, users
can create and maintain database-oriented software applications. Pony
is able to write queries to the database using generator expressions.
Pony then analyzes the abstract syntax tree of a generator and
translates it to its SQL equivalent.

%prep
%autosetup -p1 -n pony-%{version}
rm -rf pony/thirdparty/compiler
dos2unix README.md

%build
%python_build

%install
%python_install
%python_expand rm -r %{buildroot}%{$python_sitelib}/pony/*/tests
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# test_json fails with sqlite 3.45 gh#ponyorm/pony#704
rm pony/orm/tests/test_json.py
%pyunittest discover -v pony/orm/tests -p 'test_*.py'

%files %{python_files}
%doc README.md
%license LICENSE
%{python_sitelib}/pony
%{python_sitelib}/pony-%{version}*-info

%changelog
* Wed Oct 30 2024 Dirk Müller <dmueller@suse.com>
- skip for python313
* Sat Aug 31 2024 Dirk Müller <dmueller@suse.com>
- update to 0.7.19:
  * Python 3.12 support
  * Fix JSON handling in SQLite >= 3.45
* Thu Apr  4 2024 Daniel Garcia <daniel.garcia@suse.com>
- Do not run test_json, it fails with sqlite 3.45 gh#ponyorm/pony#704
* Fri Feb 16 2024 Ben Greiner <code@bnavigator.de>
- Disable python312 build: upstream is very adamant about not
  being compatible
  https://github.com/ponyorm/pony/blob/v0.7.17/setup.py#L112
* Mon Jan 22 2024 Dirk Müller <dmueller@suse.com>
- update to 0.7.17:
  * Add Python 3.11 support; drop support for Python < 3.8
  * Fix #636 nullable IntArray and StrArray
  * Fix quoting table alias in MySQL DELETE queries
  * Fix handling of default argument values in hybrid methods
    and functions
- drop python-311.patch (upstream)
* Fri Feb 24 2023 Daniel Garcia <daniel.garcia@suse.com>
- Add python-311.patch to support python 3.11,
  gh#ponyorm/pony#671
* Thu Feb 17 2022 Dirk Müller <dmueller@suse.com>
- update to 0.7.16:
  * A long-awaited support of Python 3.10.
  * A possibility to create shared-in memory SQLite databases that can be
    accessed from multiple threads
  * Fixes #628: DBAPIProvider.init() got multiple values for argument 'database'
- remove b6599465524c4b5c9624dfa30dd3c8a5624b515d.patch (upstream)
* Wed Sep 15 2021 pgajdos@suse.com
- %%check: use %%pyunittest rpm macro
* Sun Apr 18 2021 Ben Greiner <code@bnavigator.de>
- Update to 0.7.14
  * Add Python 3.9 support
  * Allow to use kwargs in select: Entity.select(**kwargs) and
    obj.collection.select(**kwargs), a feature that was announced
    but actually missed from 0.7.7
  * Add support for volatile collection attributes that don't throw
    "Phantom object appeared/disappeared" exceptions
  * Fix negative timedelta conversions
  * Pony should reconnect to PostgreSQL when receiving 57P01 error
    (AdminShutdown)
  * Allow mixing compatible types (like int and float) in
    coalesce() arguments
  * Support of subqueries in coalesce() arguments
  * Fix using aggregated subqueries in ORDER BY section
  * Fix queries with expressions like (x, y) in ((a, b), (c, d))
  * #451: KeyError for seeds with unique attributes in
    SessionCache.update_simple_index()
* Mon Mar  9 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.7.13:
  * support for python 3.8
  * minor fixes
* Wed Dec 11 2019 Tomáš Chvátal <tchvatal@suse.com>
- Require full python stack to ensure sqlite module
* Wed Apr 24 2019 pgajdos@suse.com
- version update to 0.7.10
  * Python3.7 and PyPy decompiling fixes
  * Fix reading NULL from Optional nullable array column
  * Fix handling of empty arrays in queries
  * #415: error message typo
  * #432: PonyFlask - request object can trigger teardown_request
    without real request
  * Fix GROUP CONCAT separator for MySQL
- deleted sources
  - LICENSE (not needed)
* Fri Mar  1 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.7.9:
  * Fix handling of empty arrays and empty lists in queries
  * Fix reading optional nullable array columns from database
  * Array type support for PostgreSQL and SQLite
  * isinstance() support in queries
  * Support of queries based on collections: select(x for x in y.items)
- Drop merged patch 0001-Fix-tests-failing-with-python-3.6.patch
* Thu Oct 25 2018 Jan Engelhardt <jengelh@inai.de>
- Ensure neutrality of description.
* Thu Oct 25 2018 Antonio Larrosa <alarrosa@suse.com>
- Add BuildRequires: python2 for SLE12/Leap 42.3 so tests are
  passed successfully
* Wed Oct 24 2018 Antonio Larrosa <alarrosa@suse.com>
- Added 0001-Fix-tests-failing-with-python-3.6.patch from upstream
  to fix the tests to run as expected.
* Mon Sep 24 2018 Antonio Larrosa <alarrosa@suse.com> - 0.7.6
- Initial release of python-pony 0.7.6
